@@ -1,4 +1,4 @@
-# Copyright (c) 2023, 2024, Oracle and/or its affiliates.
+# Copyright (c) 2023, 2025, Oracle and/or its affiliates.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0, as
@@ -35,7 +35,6 @@ __all__ = ["MySQLCursor"]
 import re
 import warnings
 
-from collections import namedtuple
 from decimal import Decimal
 from typing import (
     Any,
@@ -50,6 +49,7 @@ from typing import (
     Union,
 )
 
+from .._decorating import deprecated as deprecated_sync
 from .._scripting import split_multi_statement
 from ..constants import ServerFlag
 from ..cursor import (
@@ -83,8 +83,8 @@ from ..types import (
     StrOrBytes,
     WarningType,
 )
-from .abstracts import NAMED_TUPLE_CACHE, MySQLConnectionAbstract, MySQLCursorAbstract
-from .utils import deprecated
+from ._decorating import deprecated
+from .abstracts import MySQLConnectionAbstract, MySQLCursorAbstract
 
 ERR_NO_RESULT_TO_FETCH = "No result set to fetch from"
 
@@ -483,6 +483,10 @@ class MySQLCursor(MySQLCursorAbstract):
         except Exception as err:
             raise InterfaceError(f"Failed executing the operation; {err}") from None
 
+    @deprecated_sync(
+        "The property counterpart 'stored_results' will be added in a future release, "
+        "and this method will be removed."
+    )
     def stored_results(self) -> Iterator[MySQLCursorAbstract]:
         """Returns an iterator for stored results.
 
@@ -576,11 +580,6 @@ class MySQLCursor(MySQLCursorAbstract):
                 self._connection.can_consume_results = False
                 if isinstance(self, (MySQLCursorDict, MySQLCursorBufferedDict)):
                     cursor_class = MySQLCursorBufferedDict
-                elif isinstance(
-                    self,
-                    (MySQLCursorNamedTuple, MySQLCursorBufferedNamedTuple),
-                ):
-                    cursor_class = MySQLCursorBufferedNamedTuple
                 elif self._raw:
                     cursor_class = MySQLCursorBufferedRaw
                 else:
@@ -1005,64 +1004,6 @@ class MySQLCursorDict(MySQLCursor):
         ]
 
 
-class MySQLCursorNamedTuple(MySQLCursor):
-    """
-    Cursor fetching rows as named tuple.
-
-    The fetch methods of this class will return namedtuples instead of tuples.
-    Each row is returned as a namedtuple and the values can be accessed as:
-    row.col1, row.col2
-    """
-
-    def _row_to_python(
-        self,
-        rowdata: RowType,
-        desc: Optional[List[DescriptionType]] = None,  # pylint: disable=unused-argument
-    ) -> Optional[RowType]:
-        """Convert a MySQL text result row to Python types
-
-        Returns a named tuple.
-        """
-        row = rowdata
-
-        if row:
-            columns = tuple(self.column_names)
-            try:
-                named_tuple = NAMED_TUPLE_CACHE[columns]
-            except KeyError:
-                named_tuple = namedtuple("Row", columns)  # type:ignore[no-redef, misc]
-                NAMED_TUPLE_CACHE[columns] = named_tuple
-            return named_tuple(*row)
-        return None
-
-    async def fetchone(self) -> Optional[RowType]:
-        """Return next row of a query result set.
-
-        Returns:
-            tuple or None: A row from query result set.
-        """
-        row = await super().fetchone()
-        if not row:
-            return None
-        return (
-            self._row_to_python(row, self.description)
-            if hasattr(self._connection, "converter")
-            else row
-        )
-
-    async def fetchall(self) -> List[Optional[RowType]]:
-        """Return all rows of a query result set.
-
-        Returns:
-            list: A list of tuples with all rows of a query result set.
-        """
-        return [
-            self._row_to_python(row, self.description)
-            for row in await super().fetchall()
-            if row
-        ]
-
-
 class MySQLCursorBufferedDict(MySQLCursorDict, MySQLCursorBuffered):
     """
     Buffered Cursor fetching rows as dictionaries.
@@ -1095,38 +1036,6 @@ class MySQLCursorBufferedDict(MySQLCursorDict, MySQLCursorBuffered):
         return res
 
 
-class MySQLCursorBufferedNamedTuple(MySQLCursorNamedTuple, MySQLCursorBuffered):
-    """
-    Buffered Cursor fetching rows as named tuple.
-    """
-
-    async def fetchone(self) -> Optional[RowType]:
-        """Return next row of a query result set.
-
-        Returns:
-            tuple or None: A row from query result set.
-        """
-        self._check_executed()
-        row = await self._fetch_row()
-        if row:
-            return self._row_to_python(row, self.description)
-        return None
-
-    async def fetchall(self) -> List[Optional[RowType]]:
-        """Return all rows of a query result set.
-
-        Returns:
-            list: A list of tuples with all rows of a query result set.
-        """
-        if self._executed is None or self._rows is None:
-            raise InterfaceError(ERR_NO_RESULT_TO_FETCH)
-        res = []
-        for row in self._rows[self._next_row :]:
-            res.append(self._row_to_python(row, self.description))
-        self._next_row = len(self._rows)
-        return res
-
-
 class MySQLCursorPrepared(MySQLCursor):
     """Cursor using MySQL Prepared Statements"""
 
@@ -1481,105 +1390,3 @@ class MySQLCursorPreparedDict(MySQLCursorDict, MySQLCursorPrepared):  # type: ig
             for row in await super().fetchmany(size=size)
             if row
         ]
-
-
-class MySQLCursorPreparedNamedTuple(MySQLCursorNamedTuple, MySQLCursorPrepared):
-    """
-    This class is a blend of features from MySQLCursorNamedTuple and MySQLCursorPrepared
-    """
-
-    async def fetchmany(self, size: Optional[int] = None) -> List[RowType]:
-        """Return the next set of rows of a query result set.
-
-        When no more rows are available, it returns an empty list.
-        The number of rows returned can be specified using the size argument,
-        which defaults to one.
-
-        Returns:
-            list: The next set of rows of a query result set represented
-                  as a list of named tuples where column names are used as names.
-        """
-        return [
-            self._row_to_python(row, self.description)
-            for row in await super().fetchmany(size=size)
-            if row
-        ]
-
-
-class MySQLCursorPreparedRaw(MySQLCursorPrepared):
-    """
-    This class is a blend of features from MySQLCursorRaw and MySQLCursorPrepared
-    """
-
-    def __init__(
-        self,
-        connection: MySQLConnectionAbstract,
-        read_timeout: Optional[int] = None,
-        write_timeout: Optional[int] = None,
-    ):
-        super().__init__(connection, read_timeout, write_timeout)
-        self._raw: bool = True
-
-    async def fetchone(self) -> Optional[RowType]:
-        """Return next row of a query result set.
-
-        Returns:
-            tuple or None: A row from query result set.
-        """
-        self._check_executed()
-        if self._cursor_exists:
-            await self._connection.cmd_stmt_fetch(
-                self._prepared["statement_id"],
-                read_timeout=self._read_timeout,
-                write_timeout=self._write_timeout,
-            )
-        return await self._fetch_row(raw=self._raw) or None
-
-    async def fetchmany(self, size: Optional[int] = None) -> List[RowType]:
-        """Return the next set of rows of a query result set.
-
-        When no more rows are available, it returns an empty list.
-        The number of rows returned can be specified using the size argument,
-        which defaults to one.
-
-        Returns:
-            list: The next set of rows of a query result set.
-        """
-        self._check_executed()
-        res = []
-        cnt = size or self.arraysize
-        while cnt > 0 and self._have_unread_result():
-            cnt -= 1
-            row = await self._fetch_row(raw=self._raw)
-            if row:
-                res.append(row)
-        return res
-
-    async def fetchall(self) -> List[RowType]:
-        """Return all rows of a query result set.
-
-        Returns:
-            list: A list of tuples with all rows of a query result set.
-        """
-        self._check_executed()
-        rows = []
-        if self._nextrow[0]:
-            rows.append(self._nextrow[0])
-        while self._have_unread_result():
-            if self._cursor_exists:
-                await self._connection.cmd_stmt_fetch(
-                    self._prepared["statement_id"],
-                    MAX_RESULTS,
-                    read_timeout=self._read_timeout,
-                    write_timeout=self._write_timeout,
-                )
-            tmp, eof = await self._connection.get_rows(
-                raw=self._raw,
-                binary=self._binary,
-                columns=self.description,
-                read_timeout=self._read_timeout,
-            )
-            rows.extend(tmp)
-            await self._handle_eof(eof)
-        self._rowcount = len(rows)
-        return rows
